@@ -17,15 +17,19 @@ class TrackerFactory:
         :return: Tracker
         """
         parsed = urlparse(url)
-        if 'http' in parsed.scheme.lower():
+        if "http" in parsed.scheme.lower():
             return HTTPTracker(url)
-        elif 'udp' in parsed.scheme.lower():
+        elif "udp" in parsed.scheme.lower():
             return UDPTracker(url)
         else:
             raise UnknownTracker(url)
 
     @staticmethod
     def create_trackers(urls: List[str]) -> List[Tracker]:
+        """
+        Create trackers from the given url list.
+        Current options are HTTP/UDP.
+        """
         trackers = []
         for url in urls:
             tracker = TrackerFactory.create_tracker(url[0])
